changeset 2179:8bdcac47760b trunk

[svn] Keep the voiceprint inside the range for the theme.
author marvin
date Tue, 19 Dec 2006 15:13:17 -0800
parents 64ff5aaf0b18
children 10b34c6f1267
files ChangeLog audacious/visualization.c audacious/widgets/vis.c
diffstat 3 files changed, 13 insertions(+), 6 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog	Tue Dec 19 08:26:05 2006 -0800
+++ b/ChangeLog	Tue Dec 19 15:13:17 2006 -0800
@@ -1,3 +1,11 @@
+2006-12-19 16:26:05 +0000  Yoshiki Yazawa <yaz@cc.rim.or.jp>
+  revision [3361]
+  - key bindings for Save List and Save Default List had been changed accidentally.
+  
+  trunk/audacious/ui_playlist.c |    4 ++--
+  1 file changed, 2 insertions(+), 2 deletions(-)
+
+
 2006-12-19 15:54:26 +0000  William Pitcock <nenolod@nenolod.net>
   revision [3359]
   - fix all hardcoded values
--- a/audacious/visualization.c	Tue Dec 19 08:26:05 2006 -0800
+++ b/audacious/visualization.c	Tue Dec 19 15:13:17 2006 -0800
@@ -417,11 +417,10 @@
 	  
 	  /* Subsampling; 8 frequencies per sample*/
 	  for(i = 0; i < 256 ; i++)
-	    intern_vis_data[i] = (mono_freq[0][i] >> 9);
-	  
+	    intern_vis_data[i] = (mono_freq[0][i] >> 8);
 	  /* Nonlinear transfer function makes the tones stand out*/
-	  for(i = 0; i < 16 ; i++)
-	    intern_vis_data[i] = pow(2, intern_vis_data[i]);
+	  //for(i = 0; i < 16 ; i++)
+	  // intern_vis_data[i] = pow(1.2, intern_vis_data[i]);
 	}
     }
     else { /* (cfg.vis_type == VIS_SCOPE) */
--- a/audacious/widgets/vis.c	Tue Dec 19 08:26:05 2006 -0800
+++ b/audacious/widgets/vis.c	Tue Dec 19 15:13:17 2006 -0800
@@ -101,8 +101,8 @@
     else if (cfg.vis_type == VIS_VOICEPRINT && data){
       for(i = 0; i < 16; i++)
 	{
-	  /*The color palette is in the range [2-23]. This makes sure we stay there.*/
-	  vis->vs_data[i] = data[15 - i] > 23 ? 23 : data[15-i] ^ 1;
+	  /*The color palette is in the range [0-17]. This makes sure we stay there.*/
+	  vis->vs_data[i] = data[15 - i] > 17 ? 17 : data[15-i];
 	}
     }
     else if (data) {